@@ -4,52 +4,67 @@ Bond
 
 """
 
+from __future__ import annotations
+
+from typing import TypeVar
+
+from ..atoms import Atom
+
+_T = TypeVar('_T', bound='Bond')
+
 
 class Bond:
     """
     Represents an atomic bond.
 
-    Examples
-    --------
-    *Changing the Atoms of a Bond*
+    Examples:
 
-    You want to substitute the atoms in the bond for other atoms. You
-    can do this by using :meth:`.with_atoms` to create a clone of the
-    bond, which holds the replacement atoms
+        *Changing the Atoms of a Bond*
 
-    .. testcode:: changing-the-atoms-of-a-bond
+        You want to substitute the atoms in the bond for other atoms.
+        You can do this by using :meth:`.with_atoms` to create a clone
+        of the bond, which holds the replacement atoms
 
-        import stk
-        bond = stk.Bond(stk.C(0), stk.C(12), 2)
-        # Replace C(0) with H(13) but keep C(12).
-        clone = bond.with_atoms({0: stk.H(13)})
+        .. testcode:: changing-the-atoms-of-a-bond
 
-    .. testcode:: changing-the-atoms-of-a-bond
-        :hide:
+            import stk
+            bond = stk.Bond(stk.C(0), stk.C(12), 2)
+            # Replace C(0) with H(13) but keep C(12).
+            clone = bond.with_atoms({0: stk.H(13)})
 
-        assert clone.get_atom1().get_id() == 13
-        assert isinstance(clone.get_atom1(), stk.H)
-        assert clone.get_atom2().get_id() == 12
-        assert isinstance(clone.get_atom2(), stk.C)
+        .. testcode:: changing-the-atoms-of-a-bond
+            :hide:
+
+            assert clone.get_atom1().get_id() == 13
+            assert isinstance(clone.get_atom1(), stk.H)
+            assert clone.get_atom2().get_id() == 12
+            assert isinstance(clone.get_atom2(), stk.C)
 
     """
 
-    def __init__(self, atom1, atom2, order, periodicity=(0, 0, 0)):
+    def __init__(
+        self,
+        atom1: Atom,
+        atom2: Atom,
+        order: int,
+        periodicity: tuple[int, int, int] = (0, 0, 0),
+    ) -> None:
         """
         Initialize a :class:`Bond`.
 
         Parameters
         ----------
-        atom1 : :class:`.Atom`
+        atom1:
             The first atom in the bond.
 
-        atom2 : :class:`.Atom`
+        atom2:
             The second atom in the bond.
 
-        order : :class:`int`
+        order:
             The bond order.
 
-        periodicity : :class:`tuple` of :class:`int`, optional
+        periodicity:
+
             The directions across which the bond is periodic. For
             example, ``(1, 0, -1)`` means that when going from
             `atom1` to `atom2` the bond is
@@ -64,52 +79,48 @@ class Bond:
         self._order = order
         self._periodicity = periodicity
 
-    def get_atom1(self):
+    def get_atom1(self) -> Atom:
         """
         Get the first atom of the bond.
 
-        Returns
-        -------
-        :class:`.Atom`
+        Returns:
+
             The first atom of the bond.
 
         """
 
         return self._atom1
 
-    def get_atom2(self):
+    def get_atom2(self) -> Atom:
         """
         Get the second atom of the bond.
 
-        Returns
-        -------
-        :class:`.Atom`
+        Returns:
+
             The second atom of the bond.
 
         """
 
         return self._atom2
 
-    def get_order(self):
+    def get_order(self) -> int:
         """
         Get the bond order of the bond.
 
-        Returns
-        -------
-        :class:`int`
+        Returns:
+
             The bond order.
 
         """
 
         return self._order
 
-    def get_periodicity(self):
+    def get_periodicity(self) -> tuple[int, int, int]:
         """
         Get the periodicity of the bond.
 
-        Returns
-        -------
-        :class:`tuple` of :class:`int`
+        Returns:
+
             The directions across which the bond is periodic. For
             example, ``(1, 0, -1)`` means that when going from
             `atom1` to `atom2` the bond is
@@ -121,13 +132,12 @@ class Bond:
 
         return self._periodicity
 
-    def clone(self):
+    def clone(self) -> Bond:
         """
         Return a clone.
 
-        Returns
-        -------
-        :class:`.Bond`
+        Returns:
+
             The clone.
 
         """
@@ -142,7 +152,7 @@ class Bond:
         )
         return clone
 
-    def _with_atoms(self, atom_map):
+    def _with_atoms(self: _T, atom_map: dict[int, Atom]) -> _T:
         """
         Modify the bond.
 
@@ -152,44 +162,71 @@ class Bond:
         self._atom2 = atom_map.get(self._atom2.get_id(), self._atom2)
         return self
 
-    def with_atoms(self, atom_map):
+    def with_atoms(self, atom_map: dict[int, Atom]) -> Bond:
         """
         Return a clone holding different atoms.
 
-        Parameters
-        ----------
-        atom_map : :class:`dict`
-            Maps the id of an atom in the bond to the new atom the
-            clone should hold. If the id of an atom in the bond is not
-            found in `atom_map`, the atom will not be replaced in the
-            clone.
+        Parameters:
+
+            atom_map:
+                Maps the id of an atom in the bond to the new atom the
+                clone should hold. If the id of an atom in the bond is
+                not found in `atom_map`, the atom will not be replaced
+                in the clone.
+
+        Returns:
 
-        Returns
-        -------
-        :class:`.Bond`
             The clone.
 
         """
 
         return self.clone()._with_atoms(atom_map)
 
-    def is_periodic(self):
+    def with_ids(self, id_map: dict[int, int]) -> Bond:
+        """
+        Return a clone holding different atom ids.
+
+        Parameters:
+
+            id_map:
+                Maps the id of an atom in the bond to the new id the
+                clone should hold. If the id of an atom in the bond is
+                not found in `id_map`, the atom id will not be replaced
+                in the clone.
+
+        Returns:
+
+            The clone.
+
+        """
+
+        return self.clone()._with_ids(id_map)
+
+    def _with_ids(self, id_map: dict[int, int]) -> Bond:
+
+        id1 = self._atom1.get_id()
+        if id1 in id_map:
+            self._atom1 = self._atom1.with_id(id_map[id1])
+
+        id2 = self._atom2.get_id()
+        if id2 in id_map:
+            self._atom2 = self._atom2.with_id(id_map[id2])
+
+        return self
+
+    def is_periodic(self) -> bool:
         """
         Return ``True`` if the bond is periodic.
 
-        Returns
-        -------
-        :class:`bool`
+        Returns:
+
             ``True`` if the bond is periodic.
 
         """
 
         return any(direction != 0 for direction in self._periodicity)
 
-    def __repr__(self):
-        if isinstance(self._order, float) and self._order.is_integer():
-            self._order = int(self._order)
-
+    def __repr__(self) -> str:
         periodicity = (
             f', periodicity={self._periodicity}'
             if self.is_periodic()
@@ -202,5 +239,5 @@ class Bond:
             f'{self._order}{periodicity})'
         )
 
-    def __str__(self):
+    def __str__(self) -> str:
         return repr(self)
