@@ -470,7 +470,7 @@ class BuildingBlock(Molecule):
             )
         # This remake needs to be here because molecules loaded
         # with rdkit often have issues, because rdkit tries to do
-        # bits of structural analysis like stereocenters. remake
+        # bits of structural analysis like stereocenters. Remake
         # gets rid of all this problematic metadata.
         molecule = remake(cls._init_funcs[extension](path))
 
@@ -490,6 +490,13 @@ class BuildingBlock(Molecule):
         """
         Initialize from an :mod:`rdkit` molecule.
 
+        Notes
+        -----
+        For :mod:`rdkit` molecules with non-integer bond orders,
+        such as 1.5, the molecule should be kekulized prior to
+        calling this method. Otherwise, all bond orders will be
+        set to an integer value in the building block.
+
         Parameters
         ----------
         molecule : :class:`rdkit.Mol`
