@@ -4,15 +4,72 @@ M24L48
 
 """
 
-from ..cage import Cage
-from ..vertices import _NonLinearCageVertex, _LinearCageVertex
 from ...topology_graph import Edge
+from ..cage import Cage
+from ..vertices import LinearVertex, NonLinearVertex
 
 
 class M24L48(Cage):
     """
     Represents a cage topology graph.
 
+    .. moldoc::
+
+        import moldoc.molecule as molecule
+        import stk
+
+        bb1 = stk.BuildingBlock(
+            smiles='[Pd+2]',
+            functional_groups=(
+                stk.SingleAtom(stk.Pd(0, charge=2))
+                for i in range(4)
+            ),
+            position_matrix=[[0, 0, 0]],
+        )
+
+        bb2 = stk.BuildingBlock(
+            smiles=(
+                'C1=NC=CC(C2=CC=CC(C3=C'
+                'C=NC=C3)=C2)=C1'
+            ),
+            functional_groups=[
+                stk.SmartsFunctionalGroupFactory(
+                    smarts='[#6]~[#7X2]~[#6]',
+                    bonders=(1, ),
+                    deleters=(),
+                ),
+            ],
+        )
+
+        cage = stk.ConstructedMolecule(
+            topology_graph=stk.cage.M24L48(
+                building_blocks=(bb1, bb2),
+            ),
+        )
+
+        moldoc_display_molecule = molecule.Molecule(
+            atoms=(
+                molecule.Atom(
+                    atomic_number=atom.get_atomic_number(),
+                    position=position,
+                ) for atom, position in zip(
+                    cage.get_atoms(),
+                    cage.get_position_matrix(),
+                )
+            ),
+            bonds=(
+                molecule.Bond(
+                    atom1_id=bond.get_atom1().get_id(),
+                    atom2_id=bond.get_atom2().get_id(),
+                    order=(
+                        1
+                        if bond.get_order() == 9
+                        else bond.get_order()
+                    ),
+                ) for bond in cage.get_bonds()
+            ),
+        )
+
     Metal building blocks with four functional groups are
     required for this topology.
 
@@ -40,84 +97,84 @@ class M24L48(Cage):
     _coord6 = _coord5 - (_coord5-_coord1)/2
 
     _vertex_prototypes = (
-        _NonLinearCageVertex(0, [_coord1, _coord1, _coord4]),
-        _NonLinearCageVertex(1, [_coord1, _coord1, _coord5]),
-        _NonLinearCageVertex(2, [_coord1, _coord4, _coord2]),
-        _NonLinearCageVertex(3, [_coord1, _coord5, _coord2]),
-        _NonLinearCageVertex(4, [_coord1, _coord2, _coord4]),
-        _NonLinearCageVertex(5, [_coord1, _coord2, _coord5]),
-        _NonLinearCageVertex(6, [_coord1, _coord4, _coord1]),
-        _NonLinearCageVertex(7, [_coord1, _coord5, _coord1]),
-        _NonLinearCageVertex(8, [_coord2, _coord1, _coord4]),
-        _NonLinearCageVertex(9, [_coord2, _coord1, _coord5]),
-        _NonLinearCageVertex(10, [_coord2, _coord2, _coord4]),
-        _NonLinearCageVertex(11, [_coord2, _coord2, _coord5]),
-        _NonLinearCageVertex(12, [_coord2, _coord4, _coord1]),
-        _NonLinearCageVertex(13, [_coord2, _coord5, _coord1]),
-        _NonLinearCageVertex(14, [_coord2, _coord4, _coord2]),
-        _NonLinearCageVertex(15, [_coord2, _coord5, _coord2]),
-        _NonLinearCageVertex(16, [_coord4, _coord1, _coord1]),
-        _NonLinearCageVertex(17, [_coord4, _coord2, _coord1]),
-        _NonLinearCageVertex(18, [_coord4, _coord2, _coord2]),
-        _NonLinearCageVertex(19, [_coord4, _coord1, _coord2]),
-        _NonLinearCageVertex(20, [_coord5, _coord1, _coord1]),
-        _NonLinearCageVertex(21, [_coord5, _coord2, _coord1]),
-        _NonLinearCageVertex(22, [_coord5, _coord2, _coord2]),
-        _NonLinearCageVertex(23, [_coord5, _coord1, _coord2]),
+        NonLinearVertex(0, [_coord1, _coord1, _coord4]),
+        NonLinearVertex(1, [_coord1, _coord1, _coord5]),
+        NonLinearVertex(2, [_coord1, _coord4, _coord2]),
+        NonLinearVertex(3, [_coord1, _coord5, _coord2]),
+        NonLinearVertex(4, [_coord1, _coord2, _coord4]),
+        NonLinearVertex(5, [_coord1, _coord2, _coord5]),
+        NonLinearVertex(6, [_coord1, _coord4, _coord1]),
+        NonLinearVertex(7, [_coord1, _coord5, _coord1]),
+        NonLinearVertex(8, [_coord2, _coord1, _coord4]),
+        NonLinearVertex(9, [_coord2, _coord1, _coord5]),
+        NonLinearVertex(10, [_coord2, _coord2, _coord4]),
+        NonLinearVertex(11, [_coord2, _coord2, _coord5]),
+        NonLinearVertex(12, [_coord2, _coord4, _coord1]),
+        NonLinearVertex(13, [_coord2, _coord5, _coord1]),
+        NonLinearVertex(14, [_coord2, _coord4, _coord2]),
+        NonLinearVertex(15, [_coord2, _coord5, _coord2]),
+        NonLinearVertex(16, [_coord4, _coord1, _coord1]),
+        NonLinearVertex(17, [_coord4, _coord2, _coord1]),
+        NonLinearVertex(18, [_coord4, _coord2, _coord2]),
+        NonLinearVertex(19, [_coord4, _coord1, _coord2]),
+        NonLinearVertex(20, [_coord5, _coord1, _coord1]),
+        NonLinearVertex(21, [_coord5, _coord2, _coord1]),
+        NonLinearVertex(22, [_coord5, _coord2, _coord2]),
+        NonLinearVertex(23, [_coord5, _coord1, _coord2]),
 
-        _LinearCageVertex(24, [_coord1, _coord3, _coord4], False),
-        _LinearCageVertex(25, [_coord1, _coord4, _coord3], False),
-        _LinearCageVertex(26, [_coord1, _coord3, _coord5], False),
-        _LinearCageVertex(27, [_coord1, _coord5, _coord3], False),
-        _LinearCageVertex(28, [_coord2, _coord3, _coord4], False),
-        _LinearCageVertex(29, [_coord2, _coord4, _coord3], False),
-        _LinearCageVertex(30, [_coord2, _coord3, _coord5], False),
-        _LinearCageVertex(31, [_coord2, _coord5, _coord3], False),
+        LinearVertex(24, [_coord1, _coord3, _coord4], False),
+        LinearVertex(25, [_coord1, _coord4, _coord3], False),
+        LinearVertex(26, [_coord1, _coord3, _coord5], False),
+        LinearVertex(27, [_coord1, _coord5, _coord3], False),
+        LinearVertex(28, [_coord2, _coord3, _coord4], False),
+        LinearVertex(29, [_coord2, _coord4, _coord3], False),
+        LinearVertex(30, [_coord2, _coord3, _coord5], False),
+        LinearVertex(31, [_coord2, _coord5, _coord3], False),
 
-        _LinearCageVertex(32, [_coord3, _coord1, _coord4], False),
-        _LinearCageVertex(33, [_coord4, _coord1, _coord3], False),
-        _LinearCageVertex(34, [_coord3, _coord1, _coord5], False),
-        _LinearCageVertex(35, [_coord5, _coord1, _coord3], False),
-        _LinearCageVertex(36, [_coord3, _coord2, _coord4], False),
-        _LinearCageVertex(37, [_coord4, _coord2, _coord3], False),
-        _LinearCageVertex(38, [_coord3, _coord2, _coord5], False),
-        _LinearCageVertex(39, [_coord5, _coord2, _coord3], False),
+        LinearVertex(32, [_coord3, _coord1, _coord4], False),
+        LinearVertex(33, [_coord4, _coord1, _coord3], False),
+        LinearVertex(34, [_coord3, _coord1, _coord5], False),
+        LinearVertex(35, [_coord5, _coord1, _coord3], False),
+        LinearVertex(36, [_coord3, _coord2, _coord4], False),
+        LinearVertex(37, [_coord4, _coord2, _coord3], False),
+        LinearVertex(38, [_coord3, _coord2, _coord5], False),
+        LinearVertex(39, [_coord5, _coord2, _coord3], False),
 
-        _LinearCageVertex(40, [_coord3, _coord4, _coord1], False),
-        _LinearCageVertex(41, [_coord4, _coord3, _coord1], False),
-        _LinearCageVertex(42, [_coord3, _coord5, _coord1], False),
-        _LinearCageVertex(43, [_coord5, _coord3, _coord1], False),
-        _LinearCageVertex(44, [_coord3, _coord4, _coord2], False),
-        _LinearCageVertex(45, [_coord4, _coord3, _coord2], False),
-        _LinearCageVertex(46, [_coord3, _coord5, _coord2], False),
-        _LinearCageVertex(47, [_coord5, _coord3, _coord2], False),
+        LinearVertex(40, [_coord3, _coord4, _coord1], False),
+        LinearVertex(41, [_coord4, _coord3, _coord1], False),
+        LinearVertex(42, [_coord3, _coord5, _coord1], False),
+        LinearVertex(43, [_coord5, _coord3, _coord1], False),
+        LinearVertex(44, [_coord3, _coord4, _coord2], False),
+        LinearVertex(45, [_coord4, _coord3, _coord2], False),
+        LinearVertex(46, [_coord3, _coord5, _coord2], False),
+        LinearVertex(47, [_coord5, _coord3, _coord2], False),
 
-        _LinearCageVertex(48, [_coord1, _coord6, _coord6], False),
-        _LinearCageVertex(49, [_coord1, _coord6, -_coord6], False),
-        _LinearCageVertex(50, [_coord1, -_coord6, _coord6], False),
-        _LinearCageVertex(51, [_coord1, -_coord6, -_coord6], False),
-        _LinearCageVertex(52, [_coord2, _coord6, _coord6], False),
-        _LinearCageVertex(53, [_coord2, _coord6, -_coord6], False),
-        _LinearCageVertex(54, [_coord2, -_coord6, _coord6], False),
-        _LinearCageVertex(55, [_coord2, -_coord6, -_coord6], False),
+        LinearVertex(48, [_coord1, _coord6, _coord6], False),
+        LinearVertex(49, [_coord1, _coord6, -_coord6], False),
+        LinearVertex(50, [_coord1, -_coord6, _coord6], False),
+        LinearVertex(51, [_coord1, -_coord6, -_coord6], False),
+        LinearVertex(52, [_coord2, _coord6, _coord6], False),
+        LinearVertex(53, [_coord2, _coord6, -_coord6], False),
+        LinearVertex(54, [_coord2, -_coord6, _coord6], False),
+        LinearVertex(55, [_coord2, -_coord6, -_coord6], False),
 
-        _LinearCageVertex(56, [_coord6, _coord1, _coord6], False),
-        _LinearCageVertex(57, [_coord6, _coord1, -_coord6], False),
-        _LinearCageVertex(58, [-_coord6, _coord1, _coord6], False),
-        _LinearCageVertex(59, [-_coord6, _coord1, -_coord6], False),
-        _LinearCageVertex(60, [_coord6, _coord2, _coord6], False),
-        _LinearCageVertex(61, [_coord6, _coord2, -_coord6], False),
-        _LinearCageVertex(62, [-_coord6, _coord2, _coord6], False),
-        _LinearCageVertex(63, [-_coord6, _coord2, -_coord6], False),
+        LinearVertex(56, [_coord6, _coord1, _coord6], False),
+        LinearVertex(57, [_coord6, _coord1, -_coord6], False),
+        LinearVertex(58, [-_coord6, _coord1, _coord6], False),
+        LinearVertex(59, [-_coord6, _coord1, -_coord6], False),
+        LinearVertex(60, [_coord6, _coord2, _coord6], False),
+        LinearVertex(61, [_coord6, _coord2, -_coord6], False),
+        LinearVertex(62, [-_coord6, _coord2, _coord6], False),
+        LinearVertex(63, [-_coord6, _coord2, -_coord6], False),
 
-        _LinearCageVertex(64, [_coord6, _coord6, _coord1], False),
-        _LinearCageVertex(65, [_coord6, -_coord6, _coord1], False),
-        _LinearCageVertex(66, [-_coord6, _coord6, _coord1], False),
-        _LinearCageVertex(67, [-_coord6, -_coord6, _coord1], False),
-        _LinearCageVertex(68, [_coord6, _coord6, _coord2], False),
-        _LinearCageVertex(69, [_coord6, -_coord6, _coord2], False),
-        _LinearCageVertex(70, [-_coord6, _coord6, _coord2], False),
-        _LinearCageVertex(71, [-_coord6, -_coord6, _coord2], False),
+        LinearVertex(64, [_coord6, _coord6, _coord1], False),
+        LinearVertex(65, [_coord6, -_coord6, _coord1], False),
+        LinearVertex(66, [-_coord6, _coord6, _coord1], False),
+        LinearVertex(67, [-_coord6, -_coord6, _coord1], False),
+        LinearVertex(68, [_coord6, _coord6, _coord2], False),
+        LinearVertex(69, [_coord6, -_coord6, _coord2], False),
+        LinearVertex(70, [-_coord6, _coord6, _coord2], False),
+        LinearVertex(71, [-_coord6, -_coord6, _coord2], False),
     )
 
     _edge_prototypes = (
