@@ -4,28 +4,25 @@ Linear
 
 """
 
-from dataclasses import dataclass
-import numpy as np
-from typing import Tuple
+from __future__ import annotations
 
-from .vertices import (
-    _HeadVertex,
-    _TailVertex,
-    _LinearVertex,
-    _UnaligningVertex,
-)
+from dataclasses import dataclass
+
+import numpy as np
+
+from ....reactions import GenericReactionFactory
 from ...topology_graph import (
-    TopologyGraph,
     Edge,
     NullOptimizer,
+    TopologyGraph,
     Vertex,
 )
-from ....reactions import GenericReactionFactory
-
-
-__all__ = [
-    'Linear',
-]
+from .vertices import (
+    HeadVertex,
+    LinearVertex,
+    TailVertex,
+    UnaligningVertex,
+)
 
 
 class Linear(TopologyGraph):
@@ -52,10 +49,45 @@ class Linear(TopologyGraph):
             topology_graph=stk.polymer.Linear(
                 building_blocks=(bb1, bb2),
                 repeating_unit='AB',
-                num_repeating_units=12,
+                num_repeating_units=4,
             ),
         )
 
+    .. moldoc::
+
+        import moldoc.molecule as molecule
+        import stk
+
+        bb1 = stk.BuildingBlock('NCCN', [stk.PrimaryAminoFactory()])
+        bb2 = stk.BuildingBlock('O=CCC=O', [stk.AldehydeFactory()])
+        polymer = stk.ConstructedMolecule(
+            topology_graph=stk.polymer.Linear(
+                building_blocks=(bb1, bb2),
+                repeating_unit='AB',
+                num_repeating_units=4,
+            ),
+        )
+
+        moldoc_display_molecule = molecule.Molecule(
+            atoms=(
+                molecule.Atom(
+                    atomic_number=atom.get_atomic_number(),
+                    position=position,
+                ) for atom, position in zip(
+                    polymer.get_atoms(),
+                    polymer.get_position_matrix(),
+                )
+            ),
+            bonds=(
+                molecule.Bond(
+                    atom1_id=bond.get_atom1().get_id(),
+                    atom2_id=bond.get_atom2().get_id(),
+                    order=bond.get_order(),
+                ) for bond in polymer.get_bonds()
+            ),
+        )
+
+
     *Suggested Optimization*
 
     For :class:`.Linear` topologies, it is recommend to use the
@@ -72,13 +104,51 @@ class Linear(TopologyGraph):
             topology_graph=stk.polymer.Linear(
                 building_blocks=(bb1, bb2),
                 repeating_unit='AB',
-                num_repeating_units=12,
+                num_repeating_units=4,
                 # Setting scale_steps to False tends to lead to a
                 # better structure.
                 optimizer=stk.Collapser(scale_steps=False),
             ),
         )
 
+    .. moldoc::
+
+        import moldoc.molecule as molecule
+        import stk
+
+        bb1 = stk.BuildingBlock('NCCN', [stk.PrimaryAminoFactory()])
+        bb2 = stk.BuildingBlock('O=CCC=O', [stk.AldehydeFactory()])
+
+        polymer = stk.ConstructedMolecule(
+            topology_graph=stk.polymer.Linear(
+                building_blocks=(bb1, bb2),
+                repeating_unit='AB',
+                num_repeating_units=4,
+                # Setting scale_steps to False tends to lead to a
+                # better structure.
+                optimizer=stk.Collapser(scale_steps=False),
+            ),
+        )
+
+        moldoc_display_molecule = molecule.Molecule(
+            atoms=(
+                molecule.Atom(
+                    atomic_number=atom.get_atomic_number(),
+                    position=position,
+                ) for atom, position in zip(
+                    polymer.get_atoms(),
+                    polymer.get_position_matrix(),
+                )
+            ),
+            bonds=(
+                molecule.Bond(
+                    atom1_id=bond.get_atom1().get_id(),
+                    atom2_id=bond.get_atom2().get_id(),
+                    order=bond.get_order(),
+                ) for bond in polymer.get_bonds()
+            ),
+        )
+
     *Construction with Capping Units*
 
     Building blocks with a single functional group can
@@ -88,9 +158,9 @@ class Linear(TopologyGraph):
 
         import stk
 
-        bb1 = stk.BuildingBlock('NCCN', [stk.PrimaryAminoFactory()])
+        bb1 = stk.BuildingBlock('NCC(F)N', [stk.PrimaryAminoFactory()])
         bb2 = stk.BuildingBlock('O=CCC=O', [stk.AldehydeFactory()])
-        bb3 = stk.BuildingBlock('CCN', [stk.PrimaryAminoFactory()])
+        bb3 = stk.BuildingBlock('BrCCN', [stk.PrimaryAminoFactory()])
 
         polymer = stk.ConstructedMolecule(
             topology_graph=stk.polymer.Linear(
@@ -100,6 +170,42 @@ class Linear(TopologyGraph):
             ),
         )
 
+    .. moldoc::
+
+        import moldoc.molecule as molecule
+        import stk
+
+        bb1 = stk.BuildingBlock('NCC(F)N', [stk.PrimaryAminoFactory()])
+        bb2 = stk.BuildingBlock('O=CCC=O', [stk.AldehydeFactory()])
+        bb3 = stk.BuildingBlock('BrCCN', [stk.PrimaryAminoFactory()])
+
+        polymer = stk.ConstructedMolecule(
+            topology_graph=stk.polymer.Linear(
+                building_blocks=(bb1, bb2, bb3),
+                repeating_unit='ABABC',
+                num_repeating_units=1,
+            ),
+        )
+
+        moldoc_display_molecule = molecule.Molecule(
+            atoms=(
+                molecule.Atom(
+                    atomic_number=atom.get_atomic_number(),
+                    position=position,
+                ) for atom, position in zip(
+                    polymer.get_atoms(),
+                    polymer.get_position_matrix(),
+                )
+            ),
+            bonds=(
+                molecule.Bond(
+                    atom1_id=bond.get_atom1().get_id(),
+                    atom2_id=bond.get_atom2().get_id(),
+                    order=bond.get_order(),
+                ) for bond in polymer.get_bonds()
+            ),
+        )
+
     *Defining the Orientation of Each Building Block*
 
     The `orientations` parameter allows the direction of each building
@@ -110,7 +216,10 @@ class Linear(TopologyGraph):
         import stk
 
         bb1 = stk.BuildingBlock('O=CCC=O', [stk.AldehydeFactory()])
-        bb2 = stk.BuildingBlock('NCNCCN', [stk.PrimaryAminoFactory()])
+        bb2 = stk.BuildingBlock(
+            smiles='NC(Br)CN',
+            functional_groups=[stk.PrimaryAminoFactory()],
+        )
 
         p1 = stk.ConstructedMolecule(
             topology_graph=stk.polymer.Linear(
@@ -121,6 +230,46 @@ class Linear(TopologyGraph):
             ),
         )
 
+    .. moldoc::
+
+        import moldoc.molecule as molecule
+        import stk
+
+        bb1 = stk.BuildingBlock('O=CC(F)CC=O', [stk.AldehydeFactory()])
+        bb2 = stk.BuildingBlock(
+            smiles='NC(Br)CN',
+            functional_groups=[stk.PrimaryAminoFactory()],
+        )
+
+        polymer = stk.ConstructedMolecule(
+            topology_graph=stk.polymer.Linear(
+                building_blocks=(bb1, bb2),
+                repeating_unit='AB',
+                num_repeating_units=5,
+                orientations=(1, 0.5),
+                random_seed=1,
+            ),
+        )
+
+        moldoc_display_molecule = molecule.Molecule(
+            atoms=(
+                molecule.Atom(
+                    atomic_number=atom.get_atomic_number(),
+                    position=position,
+                ) for atom, position in zip(
+                    polymer.get_atoms(),
+                    polymer.get_position_matrix(),
+                )
+            ),
+            bonds=(
+                molecule.Bond(
+                    atom1_id=bond.get_atom1().get_id(),
+                    atom2_id=bond.get_atom2().get_id(),
+                    order=bond.get_order(),
+                ) for bond in polymer.get_bonds()
+            ),
+        )
+
     In the above example, ``bb1`` is guaranteed to be flipped,
     ``bb2`` has a 50% chance of being flipped, each time it is placed
     on a node.
@@ -326,7 +475,7 @@ class Linear(TopologyGraph):
 
         except ValueError:
             vertices = (
-                _UnaligningVertex(0, (0., 0., 0.), False),
+                UnaligningVertex(0, (0., 0., 0.), False),
             )
             edges = ()
 
@@ -381,7 +530,7 @@ class Linear(TopologyGraph):
 
         choices = [True, False]
         vertices = [
-            _HeadVertex(
+            HeadVertex(
                 id=0,
                 position=np.array([0, 0, 0]),
                 flip=generator.choice(
@@ -394,12 +543,12 @@ class Linear(TopologyGraph):
         for i, p in enumerate(body_orientations, 1):
             flip = generator.choice(choices, p=[p, 1-p])
             vertices.append(
-                _LinearVertex(i, np.array([i, 0, 0]), flip),
+                LinearVertex(i, np.array([i, 0, 0]), flip),
             )
             edges.append(Edge(len(edges), vertices[i-1], vertices[i]))
 
         vertices.append(
-            _TailVertex(
+            TailVertex(
                 id=len(vertices),
                 position=np.array([len(vertices), 0, 0]),
                 flip=generator.choice(
@@ -411,7 +560,7 @@ class Linear(TopologyGraph):
 
         edges.append(Edge(len(edges), vertices[-2], vertices[-1]))
 
-        return VerticesAndEdges(
+        return _VerticesAndEdges(
             vertices=tuple(vertices),
             edges=tuple(edges),
         )
@@ -431,7 +580,11 @@ class Linear(TopologyGraph):
         base = ord('A')
         return tuple(ord(letter)-base for letter in repeating_unit)
 
-    def _get_building_block_vertices(self, building_blocks, vertices):
+    def _get_building_block_vertices(
+        self,
+        building_blocks,
+        vertices,
+    ):
         polymer = self._repeating_unit*self._num_repeating_units
         building_block_vertices = {}
         for bb_index, vertex in zip(polymer, vertices):
@@ -440,9 +593,39 @@ class Linear(TopologyGraph):
                 building_block_vertices.get(bb, [])
             )
             building_block_vertices[bb].append(vertex)
+
+        building_block_vertices = self._with_unaligning_vertices(
+            building_block_vertices=building_block_vertices,
+        )
         return building_block_vertices
 
-    def _get_scale(self, building_block_vertices):
+    @staticmethod
+    def _with_unaligning_vertices(
+        building_block_vertices,
+    ):
+        clone = {}
+        for building_block, vertices in (
+            building_block_vertices.items()
+        ):
+            # Building blocks with 1 placer, cannot be aligned and
+            # must therefore use an UnaligningVertex.
+            if building_block.get_num_placers() == 1:
+                clone[building_block] = tuple(
+                    UnaligningVertex(
+                        id=vertex.get_id(),
+                        position=vertex.get_position(),
+                        flip=vertex.get_flip(),
+                    ) for vertex in vertices
+                )
+            else:
+                clone[building_block] = vertices
+
+        return clone
+
+    def _get_scale(
+        self,
+        building_block_vertices,
+    ) -> float:
         return max(
             bb.get_maximum_diameter()
             for bb in building_block_vertices
@@ -457,6 +640,6 @@ class Linear(TopologyGraph):
 
 
 @dataclass(frozen=True)
-class VerticesAndEdges:
-    vertices: Tuple[Vertex]
-    edges: Tuple[Edge]
+class _VerticesAndEdges:
+    vertices: tuple[Vertex]
+    edges: tuple[Edge]
